@@ -18,7 +18,8 @@ class LessonSubstitutionForm(forms.ModelForm):
                     "first_name__icontains",
                     "last_name__icontains",
                     "short_name__icontains",
-                ]
+                ],
+                attrs={"data-minimum-input-length": 0, "class": "browser-default"},
             )
         }
 
