@@ -1,14 +1,19 @@
 from datetime import date
 from typing import Optional, Union
 
+from django.dispatch import receiver
 from django.utils.translation import gettext_lazy as _
 
 from jsonstore import BooleanField
+from reversion.models import Revision
 
 from aleksis.core.models import Announcement, Group, Person
+from aleksis.core.util.core_helpers import get_site_preferences
 
 from .managers import TimetableType
 from .models import Lesson, LessonPeriod, Subject
+from .util.change_tracker import timetable_data_changed
+from .util.notifications import send_notifications_for_object
 
 
 @Person.property_
@@ -149,3 +154,16 @@ Person.add_permission(
     "view_person_timetable",
     _("Can view person timetable"),
 )
+
+
+@receiver(timetable_data_changed)
+def send_notifications(sender: Revision, **kwargs):
+    """Send notifications to users about the changes."""
+    if not get_site_preferences()["chronos__send_notifications_site"]:
+        return
+
+    for change in sender.changes.values():
+        if change.deleted:
+            continue
+
+        send_notifications_for_object(change.instance)
