@@ -795,24 +795,22 @@ class Exam(SchoolTermRelatedExtensibleModel):
         verbose_name=_("Lesson"),
     )
 
-    date = models.DateField(verbose_name=_("Date of exam"), null=True)
+    date = models.DateField(verbose_name=_("Date of exam"))
     period_from = models.ForeignKey(
         "TimePeriod",
         on_delete=models.CASCADE,
         verbose_name=_("Start period"),
-        null=True,
         related_name="+",
     )
     period_to = models.ForeignKey(
         "TimePeriod",
         on_delete=models.CASCADE,
         verbose_name=_("End period"),
-        null=True,
         related_name="+",
     )
 
-    title = models.CharField(verbose_name=_("Title"), max_length=255)
-    comment = models.TextField(verbose_name=_("Comment"), blank=True, null=True)
+    title = models.CharField(verbose_name=_("Title"), max_length=255, blank=True)
+    comment = models.TextField(verbose_name=_("Comment"), blank=True)
 
     class Meta:
         # Heads up: Link to period implies uniqueness per site
@@ -1217,6 +1215,15 @@ class ExtraLesson(
 
     comment = models.CharField(verbose_name=_("Comment"), blank=True, null=True, max_length=255)
 
+    exam = models.ForeignKey(
+        "Exam",
+        on_delete=models.CASCADE,
+        verbose_name=_("Related exam"),
+        related_name="extra_lessons",
+        blank=True,
+        null=True,
+    )
+
     def __str__(self):
         return f"{self.week}, {self.period}, {self.subject}"
 
@@ -1249,6 +1256,8 @@ class ExtraLesson(
 class AutomaticPlan(LiveDocument):
     """Model for configuring automatically updated PDF substitution plans."""
 
+    template = "chronos/substitutions_print.html"
+
     number_of_days = models.PositiveIntegerField(
         default=1,
         validators=[MinValueValidator(1)],
@@ -1324,19 +1333,6 @@ class AutomaticPlan(LiveDocument):
                 self.last_substitutions_revision = revision
                 self.save()
 
-    def update(self, triggered_manually: bool = True):
-        """Regenerate the PDF file with the substitutions plan."""
-        file_object, result = generate_pdf_from_template(
-            "chronos/substitutions_print.html", self.get_context_data()
-        )
-        with allow_join_result():
-            result.wait()
-            file_object.refresh_from_db()
-            if result.status == SUCCESS and file_object.file:
-                self.last_update_triggered_manually = triggered_manually
-                self.current_file.save(self.filename, file_object.file.file)
-                self.save()
-
     class Meta:
         verbose_name = _("Automatic plan")
         verbose_name_plural = _("Automatic plans")
